diff a/src/jdk.compiler/share/classes/com/sun/tools/javac/comp/CodeReflectionTransformer.java b/src/jdk.compiler/share/classes/com/sun/tools/javac/comp/CodeReflectionTransformer.java
--- /dev/null
+++ b/src/jdk.compiler/share/classes/com/sun/tools/javac/comp/CodeReflectionTransformer.java
@@ -0,0 +1,49 @@
+/*
+ * Copyright (c) 2024, Oracle and/or its affiliates. All rights reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ *
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.  Oracle designates this
+ * particular file as subject to the "Classpath" exception as provided
+ * by Oracle in the LICENSE file that accompanied this code.
+ *
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
+ *
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
+ */
+
+package com.sun.tools.javac.comp;
+
+import com.sun.tools.javac.tree.JCTree;
+import com.sun.tools.javac.tree.TreeMaker;
+import com.sun.tools.javac.util.Context;
+
+/**
+ * This is a proxy interface for the code reflection tree translator.
+ * This compiler step is optionally enabled depending on whether
+ * the incubating module jdk.incubator.code is part of the module graph.
+ */
+public interface CodeReflectionTransformer {
+    /**
+     * Analyze the code in the provided class, generating code models for the following program elements:
+     * <li>methods annotated with {@code CodeReflection};
+     * <li>lambdas or method references whose target type is {@code Quoted}; and
+     * <li>lambdas or method references whose target is an intersection type that contains {@code Quotable}.
+     * @param context the compiler context
+     * @param tree the tree to analyze
+     * @param make the tree maker
+     * @return the translated class tree
+     */
+    JCTree translateTopLevelClass(Context context, JCTree tree, TreeMaker make);
+}
